@@ -1,6 +1,6 @@
 package AnyEvent::Promises;
 {
-  $AnyEvent::Promises::VERSION = '0.04';
+  $AnyEvent::Promises::VERSION = '0.05';
 }
 use strict;
 use warnings;
@@ -22,6 +22,8 @@ sub deferred {
 sub make_promise {
     my $arg = shift;
 
+    return $arg if is_promise($arg);
+
     my $d = deferred();
     if ( ref $arg && ref $arg eq 'CODE' ) {
         $d->resolve;
@@ -51,6 +53,10 @@ sub merge_promises {
             }
         );
     }
+    if (!$left){
+        # is true only when @promises is empty
+        $d->resolve;
+    }
     return $d->promise;
 }
 
@@ -85,7 +91,7 @@ AnyEvent::Promises - simple implementation of Promises/A+ spec
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -350,10 +356,14 @@ in order they are passed to C<merge_promises>
         return @_;    # yields ('A', undef, 3)
     );
 
+When called with empty list of promises returns promise which is resolved with empty list.
+
 =item C<make_promise($arg)>
 
 Shortcut for creating promises.
 
+If C<$arg> is a promise, then C<make_promise> returns it.
+
 If C<$arg> is a coderef, then C<make_promise> is equivalent to:
 
     my $d = deferred();
